Package: MetricsWeighted
Title: Weighted Metrics and Performance Measures for Machine Learning
Version: 1.0.3
Authors@R: c(
    person("Michael", "Mayer", , "mayermichael79@gmail.com", role = c("aut", "cre")),
    person("Christian", "Lorentzen", , "lorentzen.ch@googlemail.com", role = "ctb")
  )
Description: Provides weighted versions of several metrics and performance
    measures used in machine learning, including average unit deviances of
    the Bernoulli, Tweedie, Poisson, and Gamma distributions, see
    Jorgensen B. (1997, ISBN: 978-0412997112).  The package also contains
    a weighted version of generalized R-squared, see e.g. Cohen, J. et al.
    (2002, ISBN: 978-0805822236).  Furthermore, 'dplyr' chains are
    supported.
License: GPL (>= 2)
Depends: R (>= 3.1.0)
Encoding: UTF-8
RoxygenNote: 7.2.3
Imports: graphics, stats
URL: https://github.com/mayer79/MetricsWeighted
BugReports: https://github.com/mayer79/MetricsWeighted/issues
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2023-11-16 10:33:04 UTC; Michael
Author: Michael Mayer [aut, cre],
  Christian Lorentzen [ctb]
Maintainer: Michael Mayer <mayermichael79@gmail.com>
Repository: CRAN
Date/Publication: 2023-11-16 14:23:59 UTC
Built: R 4.4.0; ; 2024-05-03 07:28:31 UTC; unix
