# Generated by roxygen2: do not edit by hand

export(AUC)
export(accuracy)
export(classification_error)
export(deviance_bernoulli)
export(deviance_gamma)
export(deviance_normal)
export(deviance_poisson)
export(deviance_tweedie)
export(elementary_score_expectile)
export(elementary_score_quantile)
export(f1_score)
export(gini_coefficient)
export(logLoss)
export(mae)
export(mape)
export(medae)
export(mse)
export(multi_metric)
export(murphy_diagram)
export(performance)
export(precision)
export(prop_within)
export(r_squared)
export(r_squared_bernoulli)
export(r_squared_gamma)
export(r_squared_poisson)
export(recall)
export(rmse)
export(weighted_cor)
export(weighted_mean)
export(weighted_median)
export(weighted_quantile)
export(weighted_var)
